==> google_cloud_monitoring-2.11.0-py2.py3-none-any.whl: google/cloud/monitoring_v3/services/metric_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import pkg_resources

import google.auth  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.api import metric_pb2  # type: ignore
from google.api import monitored_resource_pb2  # type: ignore
from google.cloud.monitoring_v3.types import metric_service
from google.protobuf import empty_pb2  # type: ignore

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-monitoring",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class MetricServiceTransport(abc.ABC):
    """Abstract transport class for MetricService."""

    AUTH_SCOPES = (
        "https://www.googleapis.com/auth/cloud-platform",
        "https://www.googleapis.com/auth/monitoring",
        "https://www.googleapis.com/auth/monitoring.read",
        "https://www.googleapis.com/auth/monitoring.write",
    )

    DEFAULT_HOST: str = "monitoring.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_monitored_resource_descriptors: gapic_v1.method.wrap_method(
                self.list_monitored_resource_descriptors,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=30.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.get_monitored_resource_descriptor: gapic_v1.method.wrap_method(
                self.get_monitored_resource_descriptor,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=30.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.list_metric_descriptors: gapic_v1.method.wrap_method(
                self.list_metric_descriptors,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=30.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.get_metric_descriptor: gapic_v1.method.wrap_method(
                self.get_metric_descriptor,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=30.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.create_metric_descriptor: gapic_v1.method.wrap_method(
                self.create_metric_descriptor,
                default_timeout=12.0,
                client_info=client_info,
            ),
            self.delete_metric_descriptor: gapic_v1.method.wrap_method(
                self.delete_metric_descriptor,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=30.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.list_time_series: gapic_v1.method.wrap_method(
                self.list_time_series,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=30.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=90.0,
                ),
                default_timeout=90.0,
                client_info=client_info,
            ),
            self.create_time_series: gapic_v1.method.wrap_method(
                self.create_time_series,
                default_timeout=12.0,
                client_info=client_info,
            ),
            self.create_service_time_series: gapic_v1.method.wrap_method(
                self.create_service_time_series,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def list_monitored_resource_descriptors(
        self,
    ) -> Callable[
        [metric_service.ListMonitoredResourceDescriptorsRequest],
        Union[
            metric_service.ListMonitoredResourceDescriptorsResponse,
            Awaitable[metric_service.ListMonitoredResourceDescriptorsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_monitored_resource_descriptor(
        self,
    ) -> Callable[
        [metric_service.GetMonitoredResourceDescriptorRequest],
        Union[
            monitored_resource_pb2.MonitoredResourceDescriptor,
            Awaitable[monitored_resource_pb2.MonitoredResourceDescriptor],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_metric_descriptors(
        self,
    ) -> Callable[
        [metric_service.ListMetricDescriptorsRequest],
        Union[
            metric_service.ListMetricDescriptorsResponse,
            Awaitable[metric_service.ListMetricDescriptorsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_metric_descriptor(
        self,
    ) -> Callable[
        [metric_service.GetMetricDescriptorRequest],
        Union[metric_pb2.MetricDescriptor, Awaitable[metric_pb2.MetricDescriptor]],
    ]:
        raise NotImplementedError()

    @property
    def create_metric_descriptor(
        self,
    ) -> Callable[
        [metric_service.CreateMetricDescriptorRequest],
        Union[metric_pb2.MetricDescriptor, Awaitable[metric_pb2.MetricDescriptor]],
    ]:
        raise NotImplementedError()

    @property
    def delete_metric_descriptor(
        self,
    ) -> Callable[
        [metric_service.DeleteMetricDescriptorRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def list_time_series(
        self,
    ) -> Callable[
        [metric_service.ListTimeSeriesRequest],
        Union[
            metric_service.ListTimeSeriesResponse,
            Awaitable[metric_service.ListTimeSeriesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def create_time_series(
        self,
    ) -> Callable[
        [metric_service.CreateTimeSeriesRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def create_service_time_series(
        self,
    ) -> Callable[
        [metric_service.CreateTimeSeriesRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("MetricServiceTransport",)

==> google_cloud_monitoring-2.16.0-py2.py3-none-any.whl: google/cloud/monitoring_v3/services/metric_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

from google.cloud.monitoring_v3 import gapic_version as package_version

import google.auth  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.api import metric_pb2  # type: ignore
from google.api import monitored_resource_pb2  # type: ignore
from google.cloud.monitoring_v3.types import metric_service
from google.protobuf import empty_pb2  # type: ignore

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


class MetricServiceTransport(abc.ABC):
    """Abstract transport class for MetricService."""

    AUTH_SCOPES = (
        "https://www.googleapis.com/auth/cloud-platform",
        "https://www.googleapis.com/auth/monitoring",
        "https://www.googleapis.com/auth/monitoring.read",
        "https://www.googleapis.com/auth/monitoring.write",
    )

    DEFAULT_HOST: str = "monitoring.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_monitored_resource_descriptors: gapic_v1.method.wrap_method(
                self.list_monitored_resource_descriptors,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=30.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.get_monitored_resource_descriptor: gapic_v1.method.wrap_method(
                self.get_monitored_resource_descriptor,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=30.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.list_metric_descriptors: gapic_v1.method.wrap_method(
                self.list_metric_descriptors,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=30.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.get_metric_descriptor: gapic_v1.method.wrap_method(
                self.get_metric_descriptor,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=30.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.create_metric_descriptor: gapic_v1.method.wrap_method(
                self.create_metric_descriptor,
                default_timeout=12.0,
                client_info=client_info,
            ),
            self.delete_metric_descriptor: gapic_v1.method.wrap_method(
                self.delete_metric_descriptor,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=30.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=30.0,
                ),
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.list_time_series: gapic_v1.method.wrap_method(
                self.list_time_series,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=30.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=90.0,
                ),
                default_timeout=90.0,
                client_info=client_info,
            ),
            self.create_time_series: gapic_v1.method.wrap_method(
                self.create_time_series,
                default_timeout=12.0,
                client_info=client_info,
            ),
            self.create_service_time_series: gapic_v1.method.wrap_method(
                self.create_service_time_series,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def list_monitored_resource_descriptors(
        self,
    ) -> Callable[
        [metric_service.ListMonitoredResourceDescriptorsRequest],
        Union[
            metric_service.ListMonitoredResourceDescriptorsResponse,
            Awaitable[metric_service.ListMonitoredResourceDescriptorsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_monitored_resource_descriptor(
        self,
    ) -> Callable[
        [metric_service.GetMonitoredResourceDescriptorRequest],
        Union[
            monitored_resource_pb2.MonitoredResourceDescriptor,
            Awaitable[monitored_resource_pb2.MonitoredResourceDescriptor],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_metric_descriptors(
        self,
    ) -> Callable[
        [metric_service.ListMetricDescriptorsRequest],
        Union[
            metric_service.ListMetricDescriptorsResponse,
            Awaitable[metric_service.ListMetricDescriptorsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_metric_descriptor(
        self,
    ) -> Callable[
        [metric_service.GetMetricDescriptorRequest],
        Union[metric_pb2.MetricDescriptor, Awaitable[metric_pb2.MetricDescriptor]],
    ]:
        raise NotImplementedError()

    @property
    def create_metric_descriptor(
        self,
    ) -> Callable[
        [metric_service.CreateMetricDescriptorRequest],
        Union[metric_pb2.MetricDescriptor, Awaitable[metric_pb2.MetricDescriptor]],
    ]:
        raise NotImplementedError()

    @property
    def delete_metric_descriptor(
        self,
    ) -> Callable[
        [metric_service.DeleteMetricDescriptorRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def list_time_series(
        self,
    ) -> Callable[
        [metric_service.ListTimeSeriesRequest],
        Union[
            metric_service.ListTimeSeriesResponse,
            Awaitable[metric_service.ListTimeSeriesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def create_time_series(
        self,
    ) -> Callable[
        [metric_service.CreateTimeSeriesRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def create_service_time_series(
        self,
    ) -> Callable[
        [metric_service.CreateTimeSeriesRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("MetricServiceTransport",)
